import request from '@/utils/request'
// 单据列表数据获取
export function GetBillList(data) {
	return request({
		url: '/api/BillMachine/GetBillList',
		method: 'post',
		data,
	})
}
// 单据详情获取
export function GetBillData(data) {
	return request({
		url: '/Api/BillMachine/GetBillData',
		method: 'post',
		data,
	})
}
// 数据库表字段集合获取
export function GetTablesCoulmn(data) {
	return request({
		url: '/Api/BillMachine/GetTablesCoulmn',
		method: 'post',
		data,
	})
}
// 保存单据
export function SaveData(data) {
	return request({
		url: '/Api/BillMachine/SaveData',
		method: 'post',
		data,
	})
}
// 删除单据
export function DelMain(data) {
	return request({
		url: '/Api/BillMachine/DelMain',
		method: 'post',
		data,
	})
}
// 删除单据数据库表行数据
export function DelTables(data) {
	return request({
		url: '/Api/BillMachine/DelTables',
		method: 'post',
		data,
	})
}
// 删除单据数据库表字段数据
export function DelTableColumn(data) {
	return request({
		url: '/Api/BillMachine/DelTableColumn',
		method: 'post',
		data,
	})
}
// 单据编号规则详情获取
export function GetBillCodeSet(data) {
	return request({
		url: '/Api/BillMachine/GetBillCodeSet',
		method: 'post',
		data,
	})
}
// 单据编号规则保存
export function SaveBillCodeSet(data) {
	return request({
		url: '/Api/BillMachine/SaveBillCodeSet',
		method: 'post',
		data,
	})
}
// 单据数据权限设置保存
export function SaveBillDataPepedomSet(data) {
	return request({
		url: '/Api/BillMachine/SaveBillDataPepedomSet',
		method: 'post',
		data,
	})
}
// 单据数据权限详情获取
export function GetBillDataPepedomSet(data) {
	return request({
		url: '/Api/BillMachine/GetBillDataPepedomSet',
		method: 'post',
		data,
	})
}
// 代码生成
export function BillMachineCreateCode(data){
	return request({
		url: '/api/BillMachine/CreateCode',
		method: 'post',
		data,
	})
}
// 代码生成-数据库生成
export function BillMachineCreateDBTables(data){
	return request({
		url: 'api/BillMachine/CreateDBTables',
		method: 'post',
		data,
	})
}
// sql校验
export function BillMachineCheckSql(data){
	return request({
		url: '/api/BillMachine/CheckSql',
		method: 'post',
		data,
	})
}
// 查询方案-获取单据查询方案
export function BillMachineGetBillQueryPlan(data){
	return request({
		url: '/api/BillMachine/GetBillQueryPlan',
		method: 'post',
		data,
	})
}
// 查询方案-保存
export function BillMachineSaveBillQueryPlan(data){
	return request({
		url: '/api/BillMachine/SaveBillQueryPlan',
		method: 'post',
		data,
	})
}
// 数据源-获取单据标准数据源
export function BillMachineGetDataSource(data){
	return request({
		url: '/api/BillMachine/GetDataSource',
		method: 'post',
		data,
	})
}
// 数据源-保存
export function BillMachineSaveDataSource(data){
	return request({
		url: '/api/BillMachine/SaveDataSource',
		method: 'post',
		data,
	})
}
// 数据源-获取单据列表显示字段（默认+个人）
export function GetDataSourcePerson(data){
	return request({
		url: 'api/BillMachine/GetDataSourcePerson',
		method: 'post',
		data,
	})
}